# FILE: GSS.sh
# PURPOSE: Configure the software to a particular device type on GSS
# CALLED BY: GSS
# REQUIRED FILES: GSS_pri.form  GSS_plo.form
# -------------------------------------------------------------------------

ERROR0="An error has been encountered in the GSS printer form file.\nPlease notify AT&T User Support.  Thank you."
ERROR1="An error has been encountered in the GSS plotter form file.\nPlease notify AT&T User Support.  Thank you."
ERROR2="The command provided was not recognized.\nPlease use Enter, Cancel, or a defined function key."

. /usr/lib/GSS_Drivers/Environment
RET=`shform -u /usr/lib/ua/GSS_pri.form`

if	[ "$?" != "0" ]
then
	message $ERROR0
	exit
fi

eval set $RET

case $1 in
# Executable code for the "enter" option follows here
	Enter)
		case $2 in
			att470|att475)
				PRINTER=att470
				DEVICE='| lp -dATT470_R'
				;;
			att455)
				PRINTER=att455
				DEVICE='| lp -dATT455_R'
				;;
			epmx80|epfx80)
				PRINTER=epmx80
				DEVICE='| lp -dEpson_R'
				;;
			epmx100)
				PRINTER=epmx100
				DEVICE='| lp -dEpson_R'
				;;
			NONE)
				PRINTER=$2
				DEVICE=""
				;;
			*)
				PRINTER=$2
				DEVICE='| lp -dOther_R'
				;;

		esac

		ed - /usr/lib/GSS_Drivers/Environment <<-!EOF
		/PRINTER/c
		PRINTER=$PRINTER; $PRINTER="$DEVICE"; export PRINTER $PRINTER
		.
		w
		q
		!EOF
	;;

# This is the Exit code if command is cancelled
	Cancel)
		exit
	;;

# Unrecognizable return from action key
	*)
		message $ERROR2
	;;

# End of printer case based on the action key
esac

RET=`shform -u /usr/lib/ua/GSS_plo.form`

if	[ "$?" != "0" ]
then
	message $ERROR1
	exit
fi

eval set $RET

case $1 in
# Executable code for the "enter" option follows here
	Enter)
		if	[ "$2" != "NONE" ]
		then
			PLOTTER=$2
			ed - /usr/lib/GSS_Drivers/Environment <<-!EOF
			/PLOTTER/c
			PLOTTER=$2; $PLOTTER=/dev/tty000; export PLOTTER $PLOTTER
			.
			w
			q
			!EOF
		else
			PLOTTER=$2
			ed - /usr/lib/GSS_Drivers/Environment <<-!EOF
			/PLOTTER/c
			PLOTTER=$2; $PLOTTER=""; export PLOTTER $PLOTTER
			.
			w
			q
			!EOF
		fi
	;;

# This is the Exit code if command is cancelled
	Cancel)
		exit
	;;

# Unrecognizable return from action key
	*)
		message $ERROR2
	;;

# End of plotter case based on the action key
esac
. /usr/lib/GSS_Drivers/Environment
echo "[2J"
